Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2726)

Unified Diff: tests/compiler/dart2js/kernel/impact_test.dart

Issue 2603263002: Prefix resolution_types with Resolution. (Closed)
Patch Set: Rebased Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/compiler/dart2js/kernel/impact_test.dart
diff --git a/tests/compiler/dart2js/kernel/impact_test.dart b/tests/compiler/dart2js/kernel/impact_test.dart
index 75795994c2b0c0f9e8580dabb04b25fe5b19ccf9..28487cde3a8e1cbe4ab1aa5be256f7ebe275746b 100644
--- a/tests/compiler/dart2js/kernel/impact_test.dart
+++ b/tests/compiler/dart2js/kernel/impact_test.dart
@@ -707,7 +707,7 @@ ResolutionImpact laxImpact(
case StaticUseKind.CONST_CONSTRUCTOR_INVOKE:
ConstructorElement constructor = staticUse.element;
ConstructorElement effectiveTarget = constructor.effectiveTarget;
- DartType effectiveTargetType =
+ ResolutionDartType effectiveTargetType =
constructor.computeEffectiveTargetType(staticUse.type);
builder.registerStaticUse(
staticUse.kind == StaticUseKind.CONST_CONSTRUCTOR_INVOKE
@@ -791,31 +791,33 @@ ResolutionImpact laxImpact(
}
/// Visitor the performers unaliasing of all typedefs nested within a
-/// [DartType].
-class Unaliaser extends BaseDartTypeVisitor<dynamic, DartType> {
+/// [ResolutionDartType].
+class Unaliaser extends BaseDartTypeVisitor<dynamic, ResolutionDartType> {
const Unaliaser();
@override
- DartType visit(DartType type, [_]) => type.accept(this, null);
+ ResolutionDartType visit(ResolutionDartType type, [_]) =>
+ type.accept(this, null);
@override
- DartType visitType(DartType type, _) => type;
+ ResolutionDartType visitType(ResolutionDartType type, _) => type;
- List<DartType> visitList(List<DartType> types) => types.map(visit).toList();
+ List<ResolutionDartType> visitList(List<ResolutionDartType> types) =>
+ types.map(visit).toList();
@override
- DartType visitInterfaceType(InterfaceType type, _) {
+ ResolutionDartType visitInterfaceType(ResolutionInterfaceType type, _) {
return type.createInstantiation(visitList(type.typeArguments));
}
@override
- DartType visitTypedefType(TypedefType type, _) {
+ ResolutionDartType visitTypedefType(ResolutionTypedefType type, _) {
return visit(type.unaliased);
}
@override
- DartType visitFunctionType(FunctionType type, _) {
- return new FunctionType.synthesized(
+ ResolutionDartType visitFunctionType(ResolutionFunctionType type, _) {
+ return new ResolutionFunctionType.synthesized(
visit(type.returnType),
visitList(type.parameterTypes),
visitList(type.optionalParameterTypes),
@@ -824,7 +826,7 @@ class Unaliaser extends BaseDartTypeVisitor<dynamic, DartType> {
}
}
-/// Perform unaliasing of all typedefs nested within a [DartType].
-DartType unalias(DartType type) {
+/// Perform unaliasing of all typedefs nested within a [ResolutionDartType].
+ResolutionDartType unalias(ResolutionDartType type) {
return const Unaliaser().visit(type);
}
« no previous file with comments | « tests/compiler/dart2js/kernel/closed_world_test.dart ('k') | tests/compiler/dart2js/least_upper_bound_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698